Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1169)

Unified Diff: webrtc/modules/audio_processing/aec/aec_core.h

Issue 1211053006: Rename APM Config ReportedDelay to DelayAgnostic (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Fix error in android test Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « talk/media/webrtc/webrtcvoiceengine.cc ('k') | webrtc/modules/audio_processing/aec/aec_core.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/audio_processing/aec/aec_core.h
diff --git a/webrtc/modules/audio_processing/aec/aec_core.h b/webrtc/modules/audio_processing/aec/aec_core.h
index 2fa26db859cc5fd8af8a17e355a5722bc1af3971..25305275609ee836d3a4deee69814478b883bdcd 100644
--- a/webrtc/modules/audio_processing/aec/aec_core.h
+++ b/webrtc/modules/audio_processing/aec/aec_core.h
@@ -103,10 +103,11 @@ void WebRtcAec_SetConfigCore(AecCore* self,
int delay_logging);
// Non-zero enables, zero disables.
-void WebRtcAec_enable_reported_delay(AecCore* self, int enable);
+void WebRtcAec_enable_delay_agnostic(AecCore* self, int enable);
-// Returns non-zero if reported delay is enabled and zero if disabled.
-int WebRtcAec_reported_delay_enabled(AecCore* self);
+// Returns non-zero if delay agnostic (i.e., signal based delay estimation) is
+// enabled and zero if disabled.
+int WebRtcAec_delay_agnostic_enabled(AecCore* self);
// Enables or disables extended filter mode. Non-zero enables, zero disables.
void WebRtcAec_enable_extended_filter(AecCore* self, int enable);
« no previous file with comments | « talk/media/webrtc/webrtcvoiceengine.cc ('k') | webrtc/modules/audio_processing/aec/aec_core.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698